@@ -162,6 +162,9 @@ function runCmd (note, cmd, pkg, env, stage, wd, unsafe, cb) {
     , group = unsafe ? null : npm.config.get("group")
 
   if (log.level !== 'silent') {
+    if (npm.spinner.int) {
+      npm.config.get("logstream").write("\r \r")
+    }
     console.log(note)
   }
   log.verbose("unsafe-perm in lifecycle", unsafe)
@@ -207,12 +210,17 @@ function runCmd_ (cmd, pkg, env, wd, stage, unsafe, uid, gid, cb_) {
   }
 
   var proc = spawn(sh, [shFlag, cmd], conf)
+  proc.on("error", procError)
   proc.on("close", function (code, signal) {
     if (signal) {
       process.kill(process.pid, signal);
     } else if (code) {
       var er = new Error("Exit status " + code)
     }
+    procError(er)
+  })
+
+  function procError (er) {
     if (er && !npm.ROLLBACK) {
       log.info(pkg._id, "Failed to exec "+stage+" script")
       er.message = pkg._id + " "
@@ -232,7 +240,7 @@ function runCmd_ (cmd, pkg, env, wd, stage, unsafe, uid, gid, cb_) {
       return cb()
     }
     cb(er)
-  })
+  }
 }
 
 
